function f = edft2(x,mrows,ncols)

% EDFT2 Two-dimensional Extended Discrete Fourier Transform.
%
% EDFT2(X) returns the two-dimensional Fourier transform of matrix X.
% Before run EDFT2 unknown data (if any) inside of X should be replaced
% by NaN (Not-a-Number).
% If X is a vector, the result will have the same orientation.
% EDFT2(X,MROWS,NCOLS) performing size MROWS-by-NCOLS Fourier transform 
% without padding of matrix X with zeros.
% The inverse transform to EDFT2 is the MATLAB library function IFFT2.
%
% See also EDFT, FFT2, IFFT2
%
% Author: Vilnis Liepins (vilnislp@gmail.com)

if nargin==0,error('Not enough input arguments.'),end
if sum(any(isinf(x))),error('Inf is not allowed in input.'),end
[m, n]=size(x);
if (nargin==1)&&(m>1)&&(n>1)
    f = edft(edft(x).').';
    return;
end
if nargin<3||isempty(ncols),ncols = n;end
if nargin<2||isempty(mrows),mrows = m;end
if m==1,mrows=ncols;end
f = edft(x,mrows);
if m>1&&n>1,f = edft(f.',ncols).'; end